@@ -102,8 +102,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -122,7 +122,7 @@ class EventsRuleToStepFunction(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         event_rule_props: aws_cdk.aws_events.RuleProps,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
@@ -146,22 +146,22 @@ class EventsRuleToStepFunction(
 
         jsii.create(EventsRuleToStepFunction, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
         return jsii.get(self, "cloudwatchAlarms")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return jsii.get(self, "eventsRule")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return jsii.get(self, "stateMachine")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return jsii.get(self, "stateMachineLogGroup")
@@ -193,7 +193,7 @@ class EventsRuleToStepFunctionProps:
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
             state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
         }
@@ -205,7 +205,9 @@ class EventsRuleToStepFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("event_rule_props")
+        result = self._values.get("event_rule_props")
+        assert result is not None, "Required property 'event_rule_props' is missing"
+        return result
 
     @builtins.property
     def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
@@ -214,12 +216,14 @@ class EventsRuleToStepFunctionProps:
         default
         :default: - None
         """
-        return self._values.get("state_machine_props")
+        result = self._values.get("state_machine_props")
+        assert result is not None, "Required property 'state_machine_props' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
